package LWP::Protocol::sbo;
use base qw(LWP::Protocol);
use strict;
use warnings;
use File::Temp;

our $VERSION = '1.00';

use HTTP::Request;
use HTTP::Response;
use HTTP::Status;

sub request {
    my ($self, $request, $proxy, $arg, $size) = @_;

    if (defined $proxy) {
	return HTTP::Response->new(HTTP::Status::RC_BAD_REQUEST,
				   'You can not proxy through the SBo archive');
    }

    unless ($request->method eq 'GET') {
	return HTTP::Response->new(HTTP::Status::HTTP_METHOD_NOT_ALLOWED,
				   "Only GET is allowed for sbo: URLs");
    }

    my $url = $request->uri;
    my $scheme = $url;
    if ($url->scheme ne 'sbo') {
	return HTTP::Response->new(HTTP::Status::RC_INTERNAL_SERVER_ERROR,
				   __PACKAGE__."::request called for '$scheme'");
    }

    my $fh = new File::Temp;
    
    eval {
	my $sbo = Net::SBo->new;
	$sbo->get($url->path, $fh->filename, treeish => $url->branch);
    };
    if ($@) {
	return HTTP::Response->new(HTTP::Status::RC_INTERNAL_SERVER_ERROR, $@);
    }

    my $response = HTTP::Response->new(HTTP::Status::RC_OK);
    $size = -s $fh;
    binmode($fh);
    $response =  $self->collect($arg, $response,
				sub {
				    my $content = "";
				    my $bytes = sysread($fh, $content, $size);
				    return \$content if $bytes > 0;
				    return \ "";
				});
    $response->header('Content-Type', 'application/x-tar');
    $response->header('Content-Length', $size);

    $response;
}

1;

    
